"use strict";var t=function(p,r){return function(){return r||p((r={exports:{}}).exports,r),r.exports}};var o=t(function(y,i){"use strict";var n=typeof Uint8ClampedArray=="function"?Uint8ClampedArray:void 0;i.exports=n});var l=t(function(d,a){"use strict";function s(){throw new Error("not implemented")}a.exports=s});var u=require("@stdlib/assert-has-uint8clampedarray-support"),c=o(),f=l(),e;u()?e=c:e=f;module.exports=e;
/**
* @license Apache-2.0
*
* Copyright (c) 2018 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/
//# sourceMappingURL=index.js.map
